==> bouml_4.16.2.orig.tar.gz: bouml_4.16.2/src/JavaGenerator/UmlClassItem.h <==
// *************************************************************************
//
// Copyright 2004-2009 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLCLASSITEM_H
#define UMLCLASSITEM_H

#include <qlist.h>

#include "UmlBaseClassItem.h"

class QTextOStream;
class UmlTypeSpec;

class UmlClassItem : public UmlBaseClassItem {
  public:
    UmlClassItem(void * id, const QCString & n)
      : UmlBaseClassItem(id, n) {
    };
  
    virtual void generate(QTextOStream & f, const QCString & cl_stereotype,
			  QCString indent) = 0;
    virtual void generate_enum_pattern_item(QTextOStream & f, int & current_value,
					    const QCString & class_name, QCString indent) = 0;
    virtual void generate_enum_pattern_case(QTextOStream & f, QCString indent) = 0;
    virtual void generate_enum_item(QTextOStream & f, QCString indent, bool & first);
    virtual void generate_enum_member(QTextOStream & f, QCString indent) = 0;
};

#endif

==> bouml_4.22.2.tar.gz: bouml_4.22.2/src/JavaGenerator/UmlClassItem.h <==
// *************************************************************************
//
// Copyright 2004-2010 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLCLASSITEM_H
#define UMLCLASSITEM_H

#include <qlist.h>

#include "UmlBaseClassItem.h"

class QTextOStream;
class UmlTypeSpec;

class UmlClassItem : public UmlBaseClassItem {
  public:
    UmlClassItem(void * id, const QCString & n)
      : UmlBaseClassItem(id, n) {
    };
  
    virtual void generate(QTextOStream & f, const QCString & cl_stereotype,
			  QCString indent) = 0;
    virtual void generate_enum_pattern_item(QTextOStream & f, int & current_value,
					    const QCString & class_name, QCString indent) = 0;
    virtual void generate_enum_pattern_case(QTextOStream & f, QCString indent) = 0;
    virtual void generate_enum_item(QTextOStream & f, QCString indent, BooL & first);
    virtual void generate_enum_member(QTextOStream & f, QCString indent) = 0;
};

#endif
